@@ -10,7 +10,7 @@ pub fn app(_attr: TokenStream, item: TokenStream) -> TokenStream {
     let items = input.items;
 
     let result = quote::quote! {
-        use mosaiq_api::*;
+        use mosaiq_app_api::*;
 
         static mut __INTERCOM: *mut Intercom = std::ptr::null_mut();
 
@@ -61,7 +61,7 @@ pub fn test_suite(_attr: TokenStream, item: TokenStream) -> TokenStream {
             #![allow(non_snake_case)]
 
             use super::mosaiq_app_c_bindings;
-            use mosaiq_api::testing::{TestSystem, InspectIntercom};
+            use mosaiq_app_api::testing::{TestSystem, InspectIntercom};
 
             static mut SYSTEM: *mut TestSystem = std::ptr::null_mut();
 
